==> loemu-0.1.0.tar.gz: loemu-0.1.0/loemu/Config.py <==

import re
import os
import sys
from ConfigParser import ConfigParser
from glob import glob
from os.path import basename,dirname

config_dir = sys.prefix + "/share/games/loemu/config/"
home_dir = os.environ['HOME'] + "/.loemu/"

class FileConfig(ConfigParser):
    def __init__(self):
        ConfigParser.__init__(self)
        self.rx=re.compile("@\(['\"]{1}(?P<section>[^(]+)['\"]{1},['\"]{1}(?P<option>[^(]+)['\"]{1}\)")
        return

    def readfiles(self,paths):
        for path in paths:
            if os.access(path,os.R_OK):
                break
        else:
            return False
        try:
            self.read(paths)
        except:
            return False
        return True

    def replace(self,match):
        return repr(self.get(match.group('section'),match.group('option')))

    def get(self,section,option):
        try:
            string=re.sub(self.rx,self.replace,ConfigParser.get(self,section,option))
        except:
            return None
        try:
            return eval(string)
        except:
            return string

class Configuration(FileConfig):
    def __init__(self):
        FileConfig.__init__(self)
        self.emulator=dict()
        return

    def load(self):
        if not self.readfiles([config_dir + "general","general"]):
            return _("Can not access to 'config' file")
        self.emulator=dict()
        
        files = set(glob("*.conf") + map(basename,glob(config_dir + "*.conf")))
        for file in files:
            c = FileConfig()
            if not c.readfiles([config_dir + file,file]):
                print _("Can not access to %s file" % file)
            else:
                self.emulator[c.get("General","label")]=c

        if not os.access(home_dir + "loemurc",os.R_OK):
            self.home_parser=FileConfig()
            self.write_configuration()
            return
        self.home_parser=FileConfig()
        self.home_parser.read([home_dir + "loemurc","loemurc"])
        self.set_home_parameters("General",self)
        for label,emu in self.emulator.iteritems():
            self.set_home_parameters(label,emu)
        return

    def write_configuration(self):
        if not os.access(os.environ['HOME'],os.W_OK):
            return _("Can not write to %s file" % home_dir + "loemurc")

        self.get_home_parameters("General",self)
        for label,emu in self.emulator.iteritems():
            self.get_home_parameters(label,emu)

        if not os.path.isdir(os.path.dirname(home_dir)):
            os.makedirs(os.path.dirname(home_dir))

        fo=file(home_dir + "loemurc","w")
        self.home_parser.write(fo)
        fo.close()

        return

    def set_home_parameters(self,section,parser):
        if not self.home_parser.has_section(section):
            return
        for option,value in self.home_parser.items(section):
            if "UserDependent" not in parser.sections():
                parser.add_section("UserDependent")
            parser.set("UserDependent",option,value)

    def get_home_parameters(self,section,parser):
        if not parser.has_section("UserDependent"):
            return
        for option in parser.options("UserDependent"):
            value = parser.get("UserDependent",option)
            if section not in self.home_parser.sections():
                self.home_parser.add_section(section)
            self.home_parser.set(section,option,value)
        return

    def emu(self,id):
        return self.emulator[id]

    def emulators(self):
        return self.emulator.keys()

==> loemu-0.1.1.tar.gz: loemu-0.1.1/loemu/Config.py <==

import re
import os
import sys
from ConfigParser import ConfigParser
from glob import glob
from os.path import basename,dirname

class FileConfig(ConfigParser):
    def __init__(self):
        ConfigParser.__init__(self)
        self.rx=re.compile("@\(['\"]{1}(?P<section>[^(]+)['\"]{1},['\"]{1}(?P<option>[^(]+)['\"]{1}\)")
        return

    def readfiles(self,paths):
        for path in paths:
            if os.access(path,os.R_OK):
                break
        else:
            return False
        try:
            self.read(paths)
        except:
            return False
        return True

    def replace(self,match):
        return repr(self.get(match.group('section'),match.group('option')))

    def get(self,section,option):
        try:
            string=re.sub(self.rx,self.replace,ConfigParser.get(self,section,option))
        except:
            return None
        try:
            return eval(string)
        except:
            return string

class Configuration(FileConfig):
    def __init__(self):
        FileConfig.__init__(self)
        self.emulator= dict()
        self.home_dir= os.environ['HOME'] + "/.loemu/"
        self.config_dir= sys.prefix + "/share/games/loemu/config/"
        return

    def load(self):
        if not self.readfiles([self.config_dir + "general","general"]):
            return _("Can not access to 'config' file")
        self.emulator=dict()
        
        files = set(glob("*.conf") + map(basename,glob(self.config_dir + "*.conf")))
        for file in files:
            c = FileConfig()
            if not c.readfiles([self.config_dir + file,file]):
                print _("Can not access to %s file" % file)
            else:
                self.emulator[c.get("General","label")]=c

        if not os.access(self.home_dir + "loemurc",os.R_OK):
            self.home_parser=FileConfig()
            self.write_configuration()
            return
        self.home_parser=FileConfig()
        self.home_parser.read([self.home_dir + "loemurc","loemurc"])
        self.set_home_parameters("General",self)
        for label,emu in self.emulator.iteritems():
            self.set_home_parameters(label,emu)
        return

    def write_configuration(self):
        if not os.access(os.environ['HOME'],os.W_OK):
            return _("Can not write to %s file" % self.home_dir + "loemurc")

        self.get_home_parameters("General",self)
        for label,emu in self.emulator.iteritems():
            self.get_home_parameters(label,emu)

        if not os.path.isdir(os.path.dirname(self.home_dir)):
            os.makedirs(os.path.dirname(self.home_dir))

        fo=file(self.home_dir + "loemurc","w")
        self.home_parser.write(fo)
        fo.close()

        return

    def set_home_parameters(self,section,parser):
        if not self.home_parser.has_section(section):
            return
        for option,value in self.home_parser.items(section):
            if "UserDependent" not in parser.sections():
                parser.add_section("UserDependent")
            parser.set("UserDependent",option,value)

    def get_home_parameters(self,section,parser):
        if not parser.has_section("UserDependent"):
            return
        for option in parser.options("UserDependent"):
            value = parser.get("UserDependent",option)
            if section not in self.home_parser.sections():
                self.home_parser.add_section(section)
            self.home_parser.set(section,option,value)
        return

    def emu(self,id):
        return self.emulator[id]

    def emulators(self):
        return self.emulator.keys()
